Welcome to the Gravitational Wave Data Manager!
================================================
This package aims at providing a unified and easy to use interface to access Gravitational Wave (GW) data and output some *well organised* datasets, ready to be used for Machine Learning projects
or Data Analysis purposes (source properties, noise studies, etc.).

Package Status
***********************

.. image:: https://gitlab.com/gwnoisehunt/gwdama/badges/master/pipeline.svg
   :alt: Main Pipeline Status
   :target: https://gitlab.com/gwnoisehunt/gwdama/-/pipelines

.. image:: https://gwnoisehunt.gitlab.io/gwdama/badges/badge-docs.svg
   :alt: Documentation Build
   :target: https://gwnoisehunt.gitlab.io/gwdama

.. image:: https://gwnoisehunt.gitlab.io/gwdama/badges/badge-registry.svg
   :alt: GitLab Package Registry Publish
   :target: https://gitlab.com/gwnoisehunt/gwdama/-/packages?type=pypi

.. image:: https://img.shields.io/website-up-down-green-red/http/shields.io.svg
   :alt: Documentation Status
   :target: https://gwnoisehunt.gitlab.io/gwdama

.. image:: https://badge.fury.io/py/gwdama.svg
   :alt: PyPI version
   :target: https://badge.fury.io/py/gwdama

.. image:: https://anaconda.org/fdirenzo/gwdama/badges/license.svg
   :alt: License
   :target: https://opensource.org/licenses/MIT


Python Compatibility
***********************
These badges are generated by the test matrix and published to GitLab Pages.

|py39| |py310| |py311| |py312|

.. |py39|  image:: https://gwnoisehunt.gitlab.io/gwdama/badges/badge-py39.svg
   :target: https://gitlab.com/gwnoisehunt/gwdama/-/pipelines
   :alt: Python 3.9 tests

.. |py310| image:: https://gwnoisehunt.gitlab.io/gwdama/badges/badge-py310.svg
   :target: https://gitlab.com/gwnoisehunt/gwdama/-/pipelines
   :alt: Python 3.10 tests

.. |py311| image:: https://gwnoisehunt.gitlab.io/gwdama/badges/badge-py311.svg
   :target: https://gitlab.com/gwnoisehunt/gwdama/-/pipelines
   :alt: Python 3.11 tests

.. |py312| image:: https://gwnoisehunt.gitlab.io/gwdama/badges/badge-py312.svg
   :target: https://gitlab.com/gwnoisehunt/gwdama/-/pipelines
   :alt: Python 3.12 tests


Documentation
***********************
The Documentation is available at `this link <https://gwnoisehunt.gitlab.io/gwdama>`_


===========
 Changelog
===========

**0.6.0**

* Added support for Python 3.12;

**0.5.2**

* Added the optional ``return_output`` parameter to ``.read_gwdata(...)`` to allow (if True) aving a Dataset or a Group as the output of this method. The corrisponding data is added in any case to the `GwDataManager <https://gwnoisehunt.gitlab.io/gwdama/gwdatamanager.html>`_ object.

**0.5.1**

* ``.plot()`` method for `Dataset <https://gwnoisehunt.gitlab.io/gwdama/dataset.html>`_ class. Mainly aimed at time sereis data, with ``t0`` and ``sample_rate`` attributes; 

**0.5.0**

* If one passes ``ffl_spec`` or ``ffl_path`` or ``gwf_path`` parameter to ``read_gwdata``, then ``data_source`` is automatically set to ``local``;
* Some parameter names have been slightly simplified. E.g.: ``m_data_source`` -> ``data_source``;
* ``hist`` method of `Dataset <https://gwnoisehunt.gitlab.io/gwdama/dataset.html>`_s now has a ``ax`` parameter to specify an existing matplotlib axes.

**0.4.5**

* Added interface with GWpy;
* Multi-Taper Method.

**0.4.1**

* Methods: ``hist``, ``duration``;
* Attributes: ``groups``;
* Preprocessing functions: ``PSD``, ``whiten``, ``taper``.

**0.4.0**

* Implemented support for data on Virgo Farm.
